FauxFactory's Documentation
===========================

FauxFactory generates random data for your automated tests easily!

.. toctree::
    :maxdepth: 2

    installation
    getting_started
    methods_available
